@@ -28,6 +28,7 @@
 #include <stdio.h>
 
 #include <glib.h>
+#include <ell/ell.h>
 
 #include <ofono/log.h>
 #include <ofono/modem.h>
@@ -338,6 +339,9 @@ static inline void at_ack_delivery(struct ofono_sms *sms)
 		case OFONO_VENDOR_GEMALTO:
 			snprintf(buf, sizeof(buf), "AT+CNMA=1");
 			break;
+		case OFONO_VENDOR_QUECTEL_SERIAL:
+			snprintf(buf, sizeof(buf), "AT+CNMA");
+			break;
 		default:
 			snprintf(buf, sizeof(buf), "AT+CNMA=1,%d\r%s",
 					data->cnma_ack_pdu_len,
@@ -921,7 +925,7 @@ static void construct_ack_pdu(struct sms_data *d)
 	if (len != tpdu_len)
 		goto err;
 
-	d->cnma_ack_pdu = encode_hex(pdu, tpdu_len, 0);
+	d->cnma_ack_pdu = l_util_hexstring(pdu, tpdu_len);
 	if (d->cnma_ack_pdu == NULL)
 		goto err;
 
@@ -1237,7 +1241,7 @@ static void at_csms_status_cb(gboolean ok, GAtResult *result,
 		if (!g_at_result_iter_next_number(&iter, &mo))
 			goto out;
 
-		if (service == 1)
+		if (service == 1 || service == 128)
 			data->cnma_enabled = TRUE;
 
 		if (mt == 1 && mo == 1)
@@ -1268,10 +1272,10 @@ static void at_csms_query_cb(gboolean ok, GAtResult *result,
 {
 	struct ofono_sms *sms = user_data;
 	struct sms_data *data = ofono_sms_get_data(sms);
-	gboolean cnma_supported = FALSE;
 	GAtResultIter iter;
 	int status_min, status_max;
 	char buf[128];
+	int csms = 0;
 
 	if (!ok)
 		return at_sms_not_supported(sms);
@@ -1284,14 +1288,25 @@ static void at_csms_query_cb(gboolean ok, GAtResult *result,
 	if (!g_at_result_iter_open_list(&iter))
 		goto out;
 
-	while (g_at_result_iter_next_range(&iter, &status_min, &status_max))
+	switch (data->vendor) {
+	case OFONO_VENDOR_QUECTEL_SERIAL:
+		g_at_result_iter_next_number(&iter, &status_min);
+		g_at_result_iter_next_number(&iter, &status_max);
 		if (status_min <= 1 && 1 <= status_max)
-			cnma_supported = TRUE;
+			csms = 128;
+		break;
+	default:
+		while (g_at_result_iter_next_range(&iter, &status_min,
+							&status_max))
+			if (status_min <= 1 && 1 <= status_max)
+				csms = 1;
+		break;
+	}
 
 	DBG("CSMS query parsed successfully");
 
 out:
-	snprintf(buf, sizeof(buf), "AT+CSMS=%d", cnma_supported ? 1 : 0);
+	snprintf(buf, sizeof(buf), "AT+CSMS=%d", csms);
 	g_at_chat_send(data->chat, buf, csms_prefix,
 			at_csms_set_cb, sms, NULL);
 }
@@ -1318,7 +1333,7 @@ static void at_sms_remove(struct ofono_sms *sms)
 {
 	struct sms_data *data = ofono_sms_get_data(sms);
 
-	g_free(data->cnma_ack_pdu);
+	l_free(data->cnma_ack_pdu);
 
 	if (data->timeout_source > 0)
 		g_source_remove(data->timeout_source);
