@@ -28,6 +28,7 @@
 #include <stdio.h>
 
 #include <glib.h>
+#include <ell/ell.h>
 
 #include <ofono/log.h>
 #include <ofono/modem.h>
@@ -87,12 +88,12 @@ static const unsigned char *ucs2_gsm_to_packed(const char *content,
 		return NULL;
 
 	if (written > 182) {
-		g_free(gsm);
+		l_free(gsm);
 		return NULL;
 	}
 
-	packed = pack_7bit_own_buf(gsm, written, 0, TRUE, msg_len, 0, msg);
-	g_free(gsm);
+	packed = pack_7bit_own_buf(gsm, written, 0, true, msg_len, 0, msg);
+	l_free(gsm);
 
 	return packed;
 }
@@ -136,7 +137,7 @@ static void cusd_parse(GAtResult *result, struct ofono_ussd *ussd)
 		switch (data->charset) {
 		case AT_UTIL_CHARSET_GSM:
 			msg_ptr = pack_7bit_own_buf((const guint8 *) content,
-							-1, 0, TRUE, &msg_len,
+							-1, 0, true, &msg_len,
 							0, msg);
 			break;
 
@@ -200,7 +201,7 @@ static void at_ussd_request(struct ofono_ussd *ussd, int dcs,
 		unsigned char unpacked_buf[182];
 		long written;
 
-		unpack_7bit_own_buf(pdu, len, 0, TRUE, sizeof(unpacked_buf),
+		unpack_7bit_own_buf(pdu, len, 0, true, sizeof(unpacked_buf),
 					&written, 0, unpacked_buf);
 
 		if (written < 1)
