@@ -30,6 +30,9 @@
 #include <string.h>
 #include <alloca.h>
 
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wcast-function-type"
+
 #include <glib.h>
 
 #include "ringbuffer.h"
@@ -949,8 +952,7 @@ gboolean g_at_mux_setup_gsm0710(GAtChat *chat,
 				mux_query_cb, msd, msd_free) > 0)
 		return TRUE;
 
-	if (msd)
-		msd_free(msd);
+	msd_free(msd);
 
 	return FALSE;
 }
